summaryrefslogtreecommitdiffstats
path: root/libhb/encx264.c
diff options
context:
space:
mode:
authorjstebbins <[email protected]>2009-11-11 17:32:37 +0000
committerjstebbins <[email protected]>2009-11-11 17:32:37 +0000
commit076050f1904ac38834352fde96c19685c8a6caea (patch)
tree007ed9f5534aa593597184235d685b321ddfd7b0 /libhb/encx264.c
parent5cc0054c9778fcb8b952e14abeab94a532e1bf5c (diff)
update x264 to r1332
Default weightp to none for baseline. user can override. git-svn-id: svn://svn.handbrake.fr/HandBrake/trunk@2922 b64f7644-9d1e-0410-96f1-a4d463321fa5
Diffstat (limited to 'libhb/encx264.c')
-rw-r--r--libhb/encx264.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libhb/encx264.c b/libhb/encx264.c
index 56bdd5ff4..bd41839a1 100644
--- a/libhb/encx264.c
+++ b/libhb/encx264.c
@@ -86,7 +86,7 @@ int encx264Init( hb_work_object_t * w, hb_job_t * job )
x264_param_default( &param );
/* Temporarily default mbtree to off for baseline,
overridable through x264 option strings. */
if( job->x264opts != NULL && *job->x264opts != '\0' )
{
@@ -124,7 +124,7 @@ int encx264Init( hb_work_object_t * w, hb_job_t * job )
{
if( atoi( value ) == 0 )
{
- param.rc.b_mb_tree = 0;
+ param.analyse.i_weighted_pred = X264_WEIGHTP_NONE;
}
}
}
@@ -86,7 +86,7 @@ int encx264Init( hb_work_object_t * w, hb_job_t * job )
x264_param_default( &param );
- /* Temporarily default mbtree to off for baseline,
+ /* Default weightp to off for baseline,
overridable through x264 option strings. */
if( job->x264opts != NULL && *job->x264opts != '\0' )